@@ -1,12 +1,24 @@
+import argparse
 import logging
 import sys
-import argparse
 from argparse import ArgumentParser
 from typing import Any, List
 
-from erdpy import (cli_accounts, cli_blockatlas, cli_config, cli_contracts,
-                   cli_cost, cli_deps, cli_dispatcher, cli_network,
-                   cli_transactions, cli_validators, cli_wallet, errors, cli_block)
+import erdpy.cli_accounts
+import erdpy.cli_block
+import erdpy.cli_blockatlas
+import erdpy.cli_config
+import erdpy.cli_contracts
+import erdpy.cli_cost
+import erdpy.cli_data
+import erdpy.cli_deps
+import erdpy.cli_dispatcher
+import erdpy.cli_network
+import erdpy.cli_testnet
+import erdpy.cli_transactions
+import erdpy.cli_validators
+import erdpy.cli_wallet
+from erdpy import errors, scope
 from erdpy._version import __version__
 
 logger = logging.getLogger("cli")
@@ -18,9 +30,15 @@ def main():
     except errors.KnownError as err:
         logger.critical(err.get_pretty())
         sys.exit(1)
+    except KeyboardInterrupt:
+        print("erdpy process killed by user.")
+        sys.exit(1)
 
 
 def _do_main():
+    logging.basicConfig(level=logging.INFO)
+    scope.initialize()
+
     parser = setup_parser()
     args = parser.parse_args()
 
@@ -61,18 +79,20 @@ https://docs.elrond.com/tools/erdpy.
     subparsers = parser.add_subparsers()
     commands: List[Any] = []
 
-    commands.append(cli_contracts.setup_parser(subparsers))
-    commands.append(cli_transactions.setup_parser(subparsers))
-    commands.append(cli_validators.setup_parser(subparsers))
-    commands.append(cli_accounts.setup_parser(subparsers))
-    commands.append(cli_wallet.setup_parser(subparsers))
-    commands.append(cli_network.setup_parser(subparsers))
-    commands.append(cli_cost.setup_parser(subparsers))
-    commands.append(cli_dispatcher.setup_parser(subparsers))
-    commands.append(cli_blockatlas.setup_parser(subparsers))
-    commands.append(cli_deps.setup_parser(subparsers))
-    commands.append(cli_config.setup_parser(subparsers))
-    commands.append(cli_block.setup_parser(subparsers))
+    commands.append(erdpy.cli_contracts.setup_parser(subparsers))
+    commands.append(erdpy.cli_transactions.setup_parser(subparsers))
+    commands.append(erdpy.cli_validators.setup_parser(subparsers))
+    commands.append(erdpy.cli_accounts.setup_parser(subparsers))
+    commands.append(erdpy.cli_wallet.setup_parser(subparsers))
+    commands.append(erdpy.cli_network.setup_parser(subparsers))
+    commands.append(erdpy.cli_cost.setup_parser(subparsers))
+    commands.append(erdpy.cli_dispatcher.setup_parser(subparsers))
+    commands.append(erdpy.cli_blockatlas.setup_parser(subparsers))
+    commands.append(erdpy.cli_deps.setup_parser(subparsers))
+    commands.append(erdpy.cli_config.setup_parser(subparsers))
+    commands.append(erdpy.cli_block.setup_parser(subparsers))
+    commands.append(erdpy.cli_testnet.setup_parser(subparsers))
+    commands.append(erdpy.cli_data.setup_parser(subparsers))
 
     parser.epilog = """
 ----------------------
