@@ -1,12 +1,13 @@
 import logging
 import os
-from typing import Any
+from typing import Any, Dict
 
 from erdpy import cli_shared, errors, projects, utils
 from erdpy.accounts import Account, Address
 from erdpy.contracts import CodeMetadata, SmartContract
 from erdpy.projects import load_project
 from erdpy.proxy.core import ElrondProxy
+from erdpy.transactions import Transaction
 
 logger = logging.getLogger("cli.contracts")
 
@@ -36,7 +37,7 @@ def setup_parser(subparsers: Any) -> Any:
 
     sub = cli_shared.add_command_subparser(subparsers, "contract", "test", "Run Mandos tests.")
     _add_project_arg(sub)
-    sub.add_argument("--directory", default="test", help="🗀 the directory containing the tests (default: %(default)s)")
+    sub.add_argument("--directory", default="mandos", help="🗀 the directory containing the tests (default: %(default)s)")
     sub.add_argument("--wildcard", required=False, help="wildcard to match only specific test files")
     sub.set_defaults(func=run_tests)
 
@@ -48,7 +49,7 @@ def setup_parser(subparsers: Any) -> Any:
     cli_shared.add_proxy_arg(sub)
     cli_shared.add_tx_args(sub, with_receiver=False, with_data=False)
     _add_arguments_arg(sub)
-    _add_send_arg(sub)
+    cli_shared.add_broadcast_args(sub)
 
     sub.set_defaults(func=deploy)
 
@@ -60,7 +61,7 @@ def setup_parser(subparsers: Any) -> Any:
     cli_shared.add_tx_args(sub, with_receiver=False, with_data=False)
     _add_function_arg(sub)
     _add_arguments_arg(sub)
-    _add_send_arg(sub)
+    cli_shared.add_broadcast_args(sub)
 
     sub.set_defaults(func=call)
 
@@ -73,7 +74,7 @@ def setup_parser(subparsers: Any) -> Any:
     cli_shared.add_proxy_arg(sub)
     cli_shared.add_tx_args(sub, with_receiver=False, with_data=False)
     _add_arguments_arg(sub)
-    _add_send_arg(sub)
+    cli_shared.add_broadcast_args(sub)
 
     sub.set_defaults(func=upgrade)
 
@@ -116,10 +117,6 @@ def _add_metadata_arg(sub: Any):
     sub.set_defaults(metadata_upgradeable=True, metadata_payable=False)
 
 
-def _add_send_arg(sub: Any):
-    sub.add_argument("--send", action="store_true", default=False, help="✓ whether to broadcast the transaction (default: %(default)s)")
-
-
 def list_templates(args: Any):
     projects.list_project_templates()
 
@@ -154,6 +151,7 @@ def run_tests(args: Any):
 
 def deploy(args: Any):
     logger.debug("deploy")
+    cli_shared.check_broadcast_args(args)
 
     arguments = args.arguments
     gas_price = args.gas_price
@@ -168,11 +166,36 @@ def deploy(args: Any):
     tx = contract.deploy(sender, arguments, gas_price, gas_limit, value, chain, version)
     logger.info("Contract address: %s", contract.address)
 
+    result = None
     try:
-        if args.send:
-            tx.send(ElrondProxy(args.proxy))
+        result = _send_or_simulate(tx, args)
     finally:
-        tx.dump_to(args.outfile, extra={"address": contract.address.bech32()})
+        txdict = tx.to_dump_dict()
+        txdict['address'] = contract.address.bech32()
+        dump_tx_and_result(txdict, result, args)
+
+
+def dump_tx_and_result(tx: Any, result: Any, args: Any):
+    dump = dict()
+    dump['emitted_tx'] = tx
+
+    try:
+        returnCode = ''
+        returnMessage = ''
+        dump['result'] = result['result']
+        for scrHash, scr in dump['result']['scResults'].items():
+            if scr['receiver'] == tx['tx']['sender']:
+                retCode = scr['data'][1:]
+                retCode = bytes.fromhex(retCode).decode('ascii')
+                returnCode = retCode
+                returnMessage = scr['returnMessage']
+
+        dump['result']['returnCode'] = returnCode
+        dump['result']['returnMessage'] = returnMessage
+    except TypeError:
+        pass
+
+    utils.dump_out_json(dump, outfile=args.outfile)
 
 
 def _prepare_contract(args: Any) -> SmartContract:
@@ -204,6 +227,7 @@ def _prepare_sender(args: Any) -> Account:
 
 def call(args: Any):
     logger.debug("call")
+    cli_shared.check_broadcast_args(args)
 
     contract_address = args.contract
     function = args.function
@@ -219,14 +243,15 @@ def call(args: Any):
 
     tx = contract.execute(sender, function, arguments, gas_price, gas_limit, value, chain, version)
     try:
-        if args.send:
-            tx.send(ElrondProxy(args.proxy))
+        result = _send_or_simulate(tx, args)
     finally:
-        tx.dump_to(args.outfile)
+        txdict = tx.to_dump_dict()
+        dump_tx_and_result(txdict, result, args)
 
 
 def upgrade(args: Any):
     logger.debug("upgrade")
+    cli_shared.check_broadcast_args(args)
 
     contract_address = args.contract
     arguments = args.arguments
@@ -242,10 +267,10 @@ def upgrade(args: Any):
 
     tx = contract.upgrade(sender, arguments, gas_price, gas_limit, value, chain, version)
     try:
-        if args.send:
-            tx.send(ElrondProxy(args.proxy))
+        result = _send_or_simulate(tx, args)
     finally:
-        tx.dump_to(args.outfile)
+        txdict = tx.to_dump_dict()
+        dump_tx_and_result(txdict, result, args)
 
 
 def query(args: Any):
@@ -257,4 +282,13 @@ def query(args: Any):
 
     contract = SmartContract(contract_address)
     result = contract.query(ElrondProxy(args.proxy), function, arguments)
-    print(result)
+    utils.dump_out_json(result)
+
+
+def _send_or_simulate(tx: Transaction, args: Any):
+    if args.send:
+        tx.send(ElrondProxy(args.proxy))
+        return None
+    elif args.simulate:
+        response = tx.simulate(ElrondProxy(args.proxy))
+        return response
