@@ -1,9 +1,12 @@
 import argparse
+import ast
 import sys
 from argparse import FileType
-from typing import Any, Text
+from typing import Any, List, Text
 
-from erdpy import config, utils
+from erdpy import config, errors, scope, utils
+from erdpy.accounts import Account
+from erdpy.proxy.core import ElrondProxy
 
 
 def wider_help_formatter(prog: Text):
@@ -62,8 +65,8 @@ def add_tx_args(sub: Any, with_nonce: bool = True, with_receiver: bool = True, w
     if with_data:
         sub.add_argument("--data", default="", help="the payload, or 'memo' of the transaction (default: %(default)s)")
 
-    sub.add_argument("--chain", default=config.get_chain_id(), help="the chain identifier (default: %(default)s)")
-    sub.add_argument("--version", type=int, default=config.get_tx_version(), help="the transaction version (default: %(default)s)")
+    sub.add_argument("--chain", default=scope.get_chain_id(), help="the chain identifier (default: %(default)s)")
+    sub.add_argument("--version", type=int, default=scope.get_tx_version(), help="the transaction version (default: %(default)s)")
 
 
 def add_wallet_args(sub: Any):
@@ -74,7 +77,7 @@ def add_wallet_args(sub: Any):
 
 
 def add_proxy_arg(sub: Any):
-    sub.add_argument("--proxy", default=config.get_proxy(), help="🖧 the URL of the proxy (default: %(default)s)")
+    sub.add_argument("--proxy", default=scope.get_proxy(), help="🖧 the URL of the proxy (default: %(default)s)")
 
 
 def add_outfile_arg(sub: Any, what: str = ""):
@@ -85,3 +88,39 @@ def add_outfile_arg(sub: Any, what: str = ""):
 def add_infile_arg(sub: Any, what: str = ""):
     what = f"({what})" if what else ""
     sub.add_argument("--infile", type=FileType("r"), required=True, help=f"input file {what}")
+
+
+def add_omit_fields_arg(sub: Any):
+    sub.add_argument("--omit-fields", default="[]", type=str, required=False, help="omit fields in the output payload (default: %(default)s)")
+
+
+def parse_omit_fields_arg(args: Any) -> List[str]:
+    literal = args.omit_fields
+    parsed = ast.literal_eval(literal)
+    return parsed
+
+
+def prepare_nonce_in_args(args: Any):
+    if args.recall_nonce:
+        if args.pem:
+            account = Account(pem_file=args.pem, pem_index=args.pem_index)
+        elif args.keyfile and args.passfile:
+            account = Account(key_file=args.keyfile, pass_file=args.passfile)
+        else:
+            raise errors.NoWalletProvided()
+
+        account.sync_nonce(ElrondProxy(args.proxy))
+        args.nonce = account.nonce
+
+
+def add_broadcast_args(sub: Any):
+    sub.add_argument("--send", action="store_true", default=False, help="✓ whether to broadcast the transaction (default: %(default)s)")
+    sub.add_argument("--simulate", action="store_true", default=False, help="whether to simulate the transaction (default: %(default)s)")
+    sub.add_argument("--relay", action="store_true", default=False, help="whether to relay the transaction (default: %(default)s)")
+
+
+def check_broadcast_args(args: Any):
+    if args.relay and args.send:
+        raise errors.BadUsage("Cannot directly send a relayed transaction. Use 'erdpy tx new --relay' first, then 'erdpy tx send --data-file'")
+    if args.send and args.simulate:
+        raise errors.BadUsage("Cannot both 'simulate' and 'send' a transaction")
