@@ -1,4 +1,3 @@
-import binascii
 import glob
 import logging
 import shutil
@@ -22,7 +21,6 @@ class Project:
         self._ensure_dependencies_installed()
         self.perform_build()
         self._copy_build_artifacts_to_output()
-        self._create_deploy_files()
 
     def clean(self):
         utils.remove_folder(self._get_output_folder())
@@ -63,22 +61,15 @@ class Project:
     def _copy_build_artifacts_to_output(self) -> None:
         raise NotImplementedError()
 
-    def _copy_to_output(self, file):
-        utils.ensure_folder(self._get_output_folder())
-        shutil.copy(file, self._get_output_folder())
+    def _copy_to_output(self, source: str, destination: str = None):
+        output_folder = self._get_output_folder()
+        utils.ensure_folder(output_folder)
+        destination = path.join(output_folder, destination) if destination else output_folder
+        shutil.copy(source, destination)
 
     def _get_output_folder(self):
         return path.join(self.directory, "output")
 
-    def _create_deploy_files(self):
-        file_wasm = self.get_file_wasm()
-        file_wasm_hex = file_wasm.with_suffix(".hex")
-
-        with open(file_wasm, "rb") as file:
-            bytecode_hex = binascii.hexlify(file.read())
-        with open(file_wasm_hex, "wb+") as file:
-            file.write(bytecode_hex)
-
     def get_bytecode(self):
         bytecode = utils.read_file(self.get_file_wasm(), binary=True)
         bytecode_hex = bytecode.hex()
