@@ -1,7 +1,7 @@
-from erdpy.accounts import Address
 import logging
-from typing import Any, Dict, List, Tuple
+from typing import Any, List, Tuple
 
+from erdpy import transactions, utils
 from erdpy.accounts import Address
 from erdpy.proxy.http_facade import do_get, do_post
 from erdpy.proxy.messages import NetworkConfig
@@ -19,19 +19,20 @@ class ElrondProxy:
     def get_account_nonce(self, address: Address) -> int:
         url = f"{self.url}/address/{address.bech32()}"
         response = do_get(url)
-        nonce = response["account"]["nonce"]
+        nonce = response.get("account").get("nonce", 0)
         return int(nonce)
 
     def get_account_balance(self, address: Address):
         url = f"{self.url}/address/{address.bech32()}/balance"
         response = do_get(url)
-        balance = response["balance"]
-        return balance
+        balance = response.get("balance", 0)
+        return int(balance)
 
     def get_account(self, address: Address):
         url = f"{self.url}/address/{address.bech32()}"
         response = do_get(url)
-        return response
+        account = response.get("account", dict())
+        return account
 
     def get_account_transactions(self, address: Address):
         TRUNCATE_DATA_THRESHOLD = 75
@@ -55,7 +56,7 @@ class ElrondProxy:
         else:
             metrics = self._get_network_status(shard_id)
 
-        nonce = metrics["erd_nonce"]
+        nonce = metrics.get("erd_highest_final_nonce", 0)
         return nonce
 
     def get_gas_price(self):
@@ -69,28 +70,33 @@ class ElrondProxy:
     def _get_network_status(self, shard_id):
         url = f"{self.url}/network/status/{shard_id}"
         response = do_get(url)
-        payload = response.get("status", None)
+        payload = response.get("status")
         return payload
 
     def get_network_config(self) -> NetworkConfig:
         url = f"{self.url}/network/config"
         response = do_get(url)
-        payload = response.get("config", None)
+        payload = response.get("config")
         result = NetworkConfig(payload)
         return result
 
     def send_transaction(self, payload: Any) -> str:
         url = f"{self.url}/transaction/send"
         response = do_post(url, payload)
-        tx_hash = response["txHash"]
+        tx_hash = response.get("txHash")
         return tx_hash
 
+    def simulate_transaction(self, payload: Any) -> str:
+        url = f"{self.url}/transaction/simulate"
+        response = do_post(url, payload)
+        return response
+
     def send_transactions(self, payload: List[Any]) -> Tuple[int, List[str]]:
         url = f"{self.url}/transaction/send-multiple"
         response = do_post(url, payload)
         # Proxy and Observers have different response format:
         num_sent = response.get("numOfSentTxs", 0) or response.get("txsSent", 0)
-        hashes = response.get("txsHashes", None)
+        hashes = response.get("txsHashes")
         return num_sent, hashes
 
     def query_contract(self, payload: Any):
@@ -98,20 +104,19 @@ class ElrondProxy:
         response = do_post(url, payload)
         return response
 
-    def get_block_by_nonce(self, nonce, with_txs=False):
-        url = f"{self.url}/block/by-nonce/{nonce}?withTxs={with_txs}"
-        response = do_get(url)
-        return response
-
-    def get_block_by_hash(self, block_hash, with_txs=False):
-        url = f"{self.url}/block/by-hash/{block_hash}?withTxs={with_txs}"
-        response = do_get(url)
-        return response
-
-    def get_transaction(self, tx_hash: str, sender_address: str) -> Any:
+    def get_transaction(self, tx_hash: str, sender_address: str = "") -> Any:
         url = f"{self.url}/transaction/{tx_hash}"
-        if sender_address != "":
-            url += f"?sender={sender_address}"
+        if sender_address:
+            url = f"{self.url}/transaction/{tx_hash}?sender={sender_address}"
+
+        response = do_get(url)
+        transaction = response.get("transaction", dict())
+        return transaction
+
+    def get_hyperblock(self, key) -> Any:
+        url = f"{self.url}/hyperblock/by-hash/{key}"
+        if str(key).isnumeric():
+            url = f"{self.url}/hyperblock/by-nonce/{key}"
 
         response = do_get(url)
         return response
