@@ -48,15 +48,29 @@ class Transaction(ITransaction):
         serialized = json.dumps(dictionary, separators=(',', ':')).encode("utf8")
         return serialized
 
+    def serialize_as_inner(self):
+        inner_dictionary = self.to_dictionary_as_inner()
+        serialized = self._dict_to_json(inner_dictionary)
+        serialized_hex = serialized.hex()
+        return f"relayedTx@{serialized_hex}"
+
     @classmethod
     def load_from_file(cls, f: Any):
         data_json: bytes = utils.read_file(f).encode()
-        fields = json.loads(data_json).get("tx", None)
+        fields = json.loads(data_json).get("tx")
         instance = cls()
         instance.__dict__.update(fields)
         instance.data = instance.data_decoded()
         return instance
 
+    def to_dump_dict(self, extra: Any = {}):
+        dump_dict: Dict[str, Any] = dict()
+        dump_dict['tx'] = self.to_dictionary()
+        dump_dict['hash'] = self.hash or ""
+        dump_dict['data'] = self.data
+        dump_dict.update(extra)
+        return dump_dict
+
     def dump_to(self, f: Any, extra: Any = {}):
         dump: Any = utils.Object()
         dump.tx = self.to_dictionary()
@@ -76,6 +90,13 @@ class Transaction(ITransaction):
         logger.info(f"Hash: {self.hash}")
         return self.hash
 
+    def simulate(self, proxy: IElrondProxy):
+        if not self.signature:
+            raise errors.TransactionIsNotSigned()
+
+        dictionary = self.to_dictionary()
+        return proxy.simulate_transaction(dictionary)
+
     def to_dictionary(self) -> Dict[str, Any]:
         dictionary: Dict[str, Any] = OrderedDict()
         dictionary["nonce"] = self.nonce
@@ -108,10 +129,7 @@ class Transaction(ITransaction):
         return dictionary
 
     def wrap_inner(self, inner: ITransaction) -> None:
-        inner_dictionary = inner.to_dictionary_as_inner()
-        serialized = self._dict_to_json(inner_dictionary)
-        serialized_hex = serialized.hex()
-        self.data = f"relayedTx@{serialized_hex}"
+        self.data = inner.serialize_as_inner()
 
 
 class BunchOfTransactions:
