@@ -5,6 +5,7 @@ import os.path
 import pathlib
 import shutil
 import stat
+import sys
 import tarfile
 import zipfile
 from pathlib import Path
@@ -12,6 +13,8 @@ from typing import Any, Dict, List, Union
 
 import toml
 
+from erdpy import errors
+
 logger = logging.getLogger("utils")
 
 
@@ -24,6 +27,21 @@ class Object:
         return data_json
 
 
+class ObjectEncoder(json.JSONEncoder):
+    def default(self, obj):
+        if isinstance(obj, Object):
+            return obj.__dict__
+        return json.JSONEncoder.default(self, obj)
+
+
+def omit_fields(data: Any, fields: List[str] = []):
+    if isinstance(data, dict):
+        for field in fields:
+            data.pop(field, None)
+        return data
+    raise errors.ProgrammingError("omit_fields: only dictionaries are supported.")
+
+
 def untar(archive_path: str, destination_folder: str) -> None:
     logger.debug(f"untar [{archive_path}] to [{destination_folder}].")
 
@@ -58,11 +76,14 @@ def read_lines(file: str):
 
 
 def read_file(f: Any, binary=False) -> Union[str, bytes]:
-    mode = "rb" if binary else "r"
-    if isinstance(f, str) or isinstance(f, pathlib.PosixPath):
-        with open(f, mode) as f:
-            return f.read()
-    return f.read()
+    try:
+        mode = "rb" if binary else "r"
+        if isinstance(f, str) or isinstance(f, pathlib.PosixPath):
+            with open(f, mode) as f:
+                return f.read()
+        return f.read()
+    except Exception as err:
+        raise errors.BadFile(f, err)
 
 
 def write_file(f: Any, text: str):
@@ -73,11 +94,11 @@ def write_file(f: Any, text: str):
 
 
 def read_toml_file(filename):
-    return toml.load(filename)
+    return toml.load(str(filename))
 
 
 def write_toml_file(filename, data):
-    with open(filename, "w") as f:
+    with open(str(filename), "w") as f:
         toml.dump(data, f)
 
 
@@ -91,8 +112,12 @@ def write_json_file(filename: str, data: Any):
         json.dump(data, f, indent=4)
 
 
-def dump_out_json(data: Any, outfile: Any):
-    json.dump(data, outfile, indent=4)
+def dump_out_json(data: Any, outfile: Any = None):
+    if not outfile:
+        outfile = sys.stdout
+
+    json.dump(data, outfile, indent=4, cls=ObjectEncoder)
+    outfile.write("\n")
 
 
 def get_subfolders(folder):
@@ -116,9 +141,13 @@ def find_in_dictionary(dictionary, compound_path):
     return node
 
 
-def list_files(folder: str) -> List[str]:
+def list_files(folder: str, suffix: str = None) -> List[str]:
     files = os.listdir(folder)
     files = [os.path.join(folder, f) for f in files]
+
+    if suffix:
+        files = [e for e in files if e.lower().endswith(suffix.lower())]
+
     return files
 
 
